@@ -79,19 +79,25 @@ def get_name_from_number(number):
                     
                     if c_num.endswith(my_num) or my_num.endswith(c_num):
                         fname = c.get_name()
-                        Log("Found name: " + fname)
-                        Log("Phonebook number: " + nr)
-                        Log("Phonebook vcard: " + "\n".join(vcardlist))
-                        Log("Stripped incoming number: " + my_num)
-                        Log("Stripped phonebook number: " + c_num)
+                        if fname != "" and fname != None:
+                            Log("Found name: " + fname)
+                            Log("Phonebook number: " + nr)
+                            Log("Phonebook vcard: " + "\n".join(vcardlist))
+                            Log("Stripped incoming number: " + my_num)
+                            Log("Stripped phonebook number: " + c_num)
                     #end if
                 #end if
                 if line.startswith("NICKNAME"):
                     tmpNick = line.split(":")[1]
-                if line.startswith("N:"):
+                if line.startswith("N:") or line.startswith("N;"):
                     tmpStr = line.split(":")[1]
-                    tmpFName = tmpStr.split(";")[1]
-                    tmpLName = tmpStr.split(";")[0]
+                    if len(tmpStr.split(";"))>1:          
+                        tmpFName = tmpStr.split(";")[1]
+                        tmpLName = tmpStr.split(";")[0]
+                    else:
+                        tmpFName = ""
+                        tmpLName = tmpStr
+                    #end if
                 #end if
             #next
             
@@ -115,11 +121,11 @@ def get_name_from_number(number):
 def headphones():
     state = open(_HEADPHONE_SYS, "r").read().strip()
     if (state == "disconnected"):
-        print "Headphones disconnected"
+        #print "Headphones disconnected"
         return False
 
     elif (state == "connected"):
-        print "Headphones connected"
+        #print "Headphones connected"
         return True
 
 #Run mixer command.
