@@ -72,10 +72,15 @@ class eSpeakCaller(QtGui.QMainWindow):
                     nr = line.split(":")[1]
                 elif line.startswith("NICKNAME"):
                     tmpNick = line.split(":")[1]
-                elif line.startswith("N:"):
+                elif line.startswith("N:") or line.startswith("N;"):
                     tmpStr = line.split(":")[1]
-                    tmpFName = tmpStr.split(";")[1]
-                    tmpLName = tmpStr.split(";")[0]
+                    if len(tmpStr.split(";"))>1:          
+                        tmpFName = tmpStr.split(";")[1]
+                        tmpLName = tmpStr.split(";")[0]
+                    else:
+                        tmpFName = ""
+                        tmpLName = tmpStr
+                    #end if
                 #end if
             #next
             
@@ -139,7 +144,7 @@ class eSpeakCaller(QtGui.QMainWindow):
                                 tmpName = tmpName.replace("%last%", self.names[contact-3][4])
                                 tmpName = tmpName.replace("%name%", self.names[contact-3][0])                             
                         #print tmpName.encode("utf-8")
-                        self.ui.lineSay.setText(tmpName)
+                        self.ui.lineSay.setText(tmpName.strip())
                     elif line.startswith("Enabled:"):
                         if line.split(":")[1] == "1":
                             self.ui.checkEnabled.setCheckState(-1)
